@@ -2,7 +2,7 @@
 #define __Common_H_INCLUDED
 
 /******** Fixing some special features of compilers **********
-(c) 1997-2021 Jaroslav Fojtik
+(c) 1997-2022 Jaroslav Fojtik
   if you don't use below mentionted compiler, please correct this items
   for your compiler and send me your correction to:
 		fojtik@penguin.cz or JaFojtik@yandex.com
@@ -129,7 +129,7 @@ Outputs:
   #if _MSC_VER >= 1400	
     #define __Strict_Const_Procs
   #endif
-  #if _MSC_VER <= 1800
+  #if _MSC_VER < 1500	/* Supported since MSVC 2008 */
     #define vsnprintf _vsnprintf
   #endif
   #define NO_LVAL_CAST
@@ -172,7 +172,7 @@ typedef enum
  #ifdef __cplusplus
   extern "C" {
  #endif
- void RaiseError(int ErrNo, void *Instance);
+ void RaiseError(int ErrNo, const void *Instance);
  #ifdef __cplusplus
   }
  #endif
