@@ -79,6 +79,12 @@ int StrNCmp(const char *str1,const char *str2,int str_size);
 #endif
 
 
+#if defined(__ARMCC_VERSION)
+extern "C" {
+char *strdup(const char *str);
+}
+#endif
+
 /** This function fixes up the error in duplicating NULL string. */
 inline char *StrDup (const char *source)
 {
