@@ -1,8 +1,7 @@
 #ifndef _TYPEDEFS_H_
 #define _TYPEDEFS_H_
-
 /******** Definition of items with uniquely size **********
-(c) 1997-2021 Jaroslav Fojtik
+(c) 1997-2022 Jaroslav Fojtik
    if you don't use below mentionted compiler, please correct this items
    for your compiler and send me your correction to:
 			fojtik@penguin.cz or JaFojtik@yandex.com
@@ -20,7 +19,6 @@ List of supported types:
 
 ***************************************************************/
 
-
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -51,11 +49,11 @@ extern "C" {
 
 #if defined(__EGC__) || defined(__GNUC__)
  #define NATIVE_ACCESS
- #ifdef __MINGW32__
+ #if defined(__MINGW32__) || defined(__MINGW64__)
   #include <basetsd.h>
  #endif
 
- #if (__BYTE_ORDER__==__ORDER_LITTLE_ENDIAN__) || defined(__DJGPP__) || defined(__MINGW32__)
+ #if (__BYTE_ORDER__==__ORDER_LITTLE_ENDIAN__) || defined(__DJGPP__) || defined(__MINGW32__) || defined(__MINGW64__)
   #ifndef LO_ENDIAN
    #define LO_ENDIAN
   #endif
@@ -73,7 +71,7 @@ extern "C" {
   typedef int __s16 __attribute__((mode(HI)));
   typedef unsigned int __u16 __attribute__((mode(HI)));
   typedef int __s32 __attribute__((mode(SI)));
-  #ifndef __MINGW32__
+  #if !defined(__MINGW32__) && !defined(__MINGW64__)
    typedef unsigned int __u32 __attribute__((mode(SI)));
   #endif
   typedef int __s64 __attribute__((mode(DI)));
@@ -285,6 +283,7 @@ void ST_FLOAT_SWAP(void *b, float f);
   #define ST_FLOAT_HI(ptr,val)	ST_FLOAT_SWAP(ptr,val)
   #define LD_DOUBLE_HI(ptr)	LD_DOUBLE_SWAP(ptr)
   #define ST_DOUBLE_HI(ptr,val)	ST_DOUBLE_SWAP(ptr,val)
+  #define LD_FLOAT_LO(ptr)	LD_UINT32_CPU(ptr)
  #endif
 
  #ifdef HI_ENDIAN
@@ -296,6 +295,8 @@ void ST_FLOAT_SWAP(void *b, float f);
    #define LD_UINT64_HI(ptr)	LD_UINT64_CPU(ptr)
    #define ST_UINT64_HI(ptr,val) ST_UINT64_CPU(ptr,val)
   #endif
+  #define LD_FLOAT_HI(ptr)	LD_UINT32_CPU(ptr)
+  #define LD_FLOAT_LO(ptr)	LD_FLOAT_SWAP(ptr)
  #endif
 #endif
 
