@@ -345,6 +345,17 @@ TImageFileHandler HANDLER_##SUFFIX(EXTENSION,
 #else
 	NULL);
 #endif
+#if SupportTGA>=4 || SupportTGA==2
+ ImplementReader(ICB,".ICB")
+	LoadPictureTGA,
+	NULL);
+ ImplementReader(VDA,".VDA")
+	LoadPictureTGA,
+	NULL);
+ ImplementReader(VST,".VST")
+	LoadPictureTGA,
+	NULL);
+#endif
 #endif
 
 
@@ -437,6 +448,38 @@ TImageFileHandler TIFF_H(".TIFF",
 #endif
 
 
+#if defined(SupportXPM) && SupportXPM>=2
+ ImplementReader(XPM3,".XPM")
+ #if SupportXPM>=4 || SupportXPM==2
+	LoadPictureXPM3,
+ #else
+	NULL,
+ #endif
+ #if SupportXPM>=3
+ 	SavePictureXPM3,
+ #else
+	NULL,
+ #endif
+        "3");
+#endif
+
+
+#if defined(SupportXPM) && SupportXPM>=2
+ ImplementReader(XPM2,".XPM")
+ #if SupportXPM>=4 || SupportXPM==2
+	LoadPictureXPM2,
+ #else
+	NULL,
+ #endif
+ //#if SupportXPM>=3
+ //	SavePictureXPM);
+ //#else
+	NULL,
+ //#endif
+        "2");
+#endif
+
+
 /////////////////////////////////////////////////
 
 
