@@ -32,6 +32,7 @@
  #define SupportTXTgm 0
  #define SupportWMF 1
  #define SupportWPG 1	//Compile only supporting stub, build-in reader included
+ #define SupportXPM 0
 #else
  #define SupportART 2 	//Read procedure only
  #define SupportBMP 2	//Read procedure only
@@ -48,6 +49,7 @@
  #define SupportTXT 2	//Read procedure only
  #define SupportWMF 2
  #define SupportWPG 1	//Compile only supporting stub, build-in reader included
+ #define SupportXPM 2
 #endif
 #define SupportFTG  0
 
@@ -125,6 +127,9 @@
 #ifndef SupportWPG
   #define SupportWPG  10
 #endif
+#ifndef SupportXPM
+  #define SupportXPM  10
+#endif
 
 
 #ifndef SupportJPG
