@@ -9,6 +9,9 @@
 #include<stdio.h>
 #include<string.h>
 #include<stdlib.h>
+#ifdef HI_ENDIAN
+ #include <byteswap.h>
+#endif
 
 #include "common.h"
 
@@ -1826,14 +1829,23 @@ void Raster1D_16BitRGB::PTR_SetValue1D(void *RAW_Data1D, unsigned x, DWORD NewVa
 DWORD Raster1D_8BitRGBA::GetValue1D(unsigned x) const
 {
   if(x>=Size1D) return 0;
+#ifdef HI_ENDIAN
+  return  __builtin_bswap32(((DWORD *)Data1D)[x]);
+#else
   return ((DWORD *)Data1D)[x];
+#endif
 }
 
 
 void Raster1D_8BitRGBA::SetValue1D(unsigned x, DWORD NewValue)
 {
   if(Size1D<=x) return;
-  ((DWORD *)Data1D)[x] = NewValue;
+  ((DWORD *)Data1D)[x] = 
+#ifdef HI_ENDIAN
+	 __builtin_bswap32(NewValue);
+#else
+	NewValue;
+#endif
 }
 
 
@@ -1841,7 +1853,12 @@ void Raster1D_8BitRGBA::SetValue1D(unsigned x, DWORD NewValue)
 void Raster1D_8BitRGBA::PTR_SetValue1D(void *RAW_Data1D, unsigned x, DWORD NewValue) const
 {
   if(Size1D<=x) return;
-  ((DWORD *)RAW_Data1D)[x] = NewValue;
+  ((DWORD *)RAW_Data1D)[x] =
+#ifdef HI_ENDIAN
+	 __builtin_bswap32(NewValue);
+#else
+	NewValue;
+#endif
 }
 #endif
 
@@ -2059,7 +2076,7 @@ Raster1DAbstract *Raster2DAbstract::GetRowRaster(unsigned Offset2D)
 
 void Raster2DAbstract::Get(unsigned Offset2D, Raster1DAbstract &R1) MP_CONST
 {
-  if(Data2D==NULL || Offset2D>=Size2D) return;  
+  if(Data2D==NULL || Offset2D>=Size2D) return;
 #ifdef _REENTRANT
   Raster1DAbstract::PTR_Get(Data2D[Offset2D],R1);
 #else
