@@ -10,7 +10,7 @@
 
 #include "typedfs.h"
 
-#define RASTER_VERSION (0x100*0 | 21)
+#define RASTER_VERSION (0x100*0 | 22)
 
 #ifndef No_Memory
  #define No_Memory    0x1
@@ -226,7 +226,7 @@ public:
   unsigned B(unsigned x) const {return(GetValue1DRAW(4*x+2));}
   unsigned A(unsigned x) const {return(GetValue1DRAW(4*x+3));}
 
-  void R(unsigned x, unsigned newR) {SetValue1DRAW(4*x,newR);};
+  void R(unsigned x, unsigned newR) {SetValue1DRAW(4*x  ,newR);};
   void G(unsigned x, unsigned newG) {SetValue1DRAW(4*x+1,newG);};
   void B(unsigned x, unsigned newB) {SetValue1DRAW(4*x+2,newB);};
   void A(unsigned x, unsigned newA) {SetValue1DRAW(4*x+3,newA);};
@@ -240,6 +240,8 @@ protected:
 #endif
 };
 
+Raster1DAbstractRGBA *CreateRaster1DRGBA(unsigned Size1D, int Planes);
+
 
 class Raster2DAbstract: virtual public Raster1DAbstract
 {
@@ -387,6 +389,8 @@ void Flip3D(Raster3DAbstract *r3D);
 
 /* ---------- Global class Image --------- */
 
+#define RAS_IMG_VERSION (0x200 | 57)
+
 /*Definition of errors while Loading/Saving File(s)*/
 #define ErrOK		  0
 #define ErrOpenFile	 -1
@@ -492,7 +496,7 @@ void Flip1D(Raster1DAbstract *r1D);
 void Flip1D(Raster2DAbstract *r2D);
 void Flip2D(Raster2DAbstract *r2D);
 int ReducePalette(Image *Img, unsigned maxColors);
-int GrayPalette(Raster1DAbstractRGB *Palette,int Planes=0);
+int GrayPalette(APalette *Palette, int Planes=0);
 int FillGray(Raster1DAbstractRGB *Palette,int Planes);
 
 
