@@ -1,5 +1,5 @@
 /******************************************************************************
- * program:     rasimg library 0.21                                           *
+ * program:     rasimg library 0.22                                           *
  * function:    Miscellaneous utilities for manipulation with images.         *
  * modul:       rasterut.cc                                                   *
  * licency:     GPL or LGPL                                                   *
@@ -612,9 +612,9 @@ BYTE *ptrb;
  if(RGB==NULL || Data1D==NULL || Size1D<index) return;
  index *= 6; 
  ptrb = ((BYTE *)Data1D)+index;
- RGB->R = *ptrb;	ptrb += 2;
- RGB->G = *ptrb;	ptrb += 2;
- RGB->B = *ptrb;
+ RGB->R = *(WORD*)ptrb;		ptrb += 2;
+ RGB->G = *(WORD*)ptrb;		ptrb += 2;
+ RGB->B = *(WORD*)ptrb;
 }
 
 
@@ -658,7 +658,7 @@ return(pal);
 
 
 /** Is this Gray scale palette? */
-int GrayPalette(Raster1DAbstractRGB *Palette, int Planes)
+int GrayPalette(APalette *Palette, int Planes)
 {
 unsigned i;
 unsigned PalItems;
@@ -667,6 +667,8 @@ unsigned PalItems;
  if(Palette->Data1D==NULL ||
     Palette->Size1D==0) return(1);	//consider invalid palette to be gray
 
+ if(Planes==0) Planes = Palette->GetPlanes() / Palette->Channels();
+ if(Planes >= sizeof(PalItems)*8) return 0; // Shift operation will overflow, consider image to be color.
  PalItems = (1<<Planes);
  if(Planes!=0)
    if(PalItems > Palette->GetSize1D())
@@ -675,12 +677,17 @@ unsigned PalItems;
 	return(0);	//insufficient palette size, ?? non gray ??
 	}
 
- for(i=0;i<PalItems;i++)
+ const unsigned divider = (PalItems>1) ? (PalItems - 1) : 1;
+ const unsigned multiplayer = (Planes>8) ? 65535 : 255;
+ for(i=0; i<PalItems; i++)
 	{
-	const unsigned color = i*255 / (PalItems-1);
-	if( (Palette->R(i)!=color) ||
-	    (Palette->G(i)!=color) ||
-	    (Palette->B(i)!=color) ) return(0);
+	const unsigned color = i*multiplayer / divider;
+        RGBQuad RGB;
+        Palette->Get(i,&RGB);
+	if((RGB.R!=color) ||
+	   (RGB.G!=color) ||
+	   (RGB.B!=color) )
+			return(0);
 	}
  return(1);
 }
@@ -695,11 +702,16 @@ unsigned i;
  if(Palette->Data1D==NULL) return(0);
 
  if(Planes!=0)
-   if(3*Planes*8 != Palette->GetPlanes()) return(0);
+   if(3*Planes != Palette->GetPlanes()) return(0);
+
+ unsigned Divider = (Palette->Size1D-1);
+ if(Divider==0) Divider=1;
+
+ unsigned Multiplier = (Palette->GetPlanes()/Palette->Channels()<=8) ? 255 : 65535;
 
  for(i=0; i<Palette->Size1D; i++)
    {
-   const unsigned color = i*255 / (Palette->Size1D-1);
+   const unsigned color = i*Multiplier / Divider;
    Palette->R(i,color);
    Palette->G(i,color);
    Palette->B(i,color);
