@@ -838,7 +838,7 @@ DWORD begincp, endcp;
 		 wvConvertCPToFC(i, &cq->clx),
 		 cq->btePapx, cq->posPapx, cq->para_intervals, cq->wpd);
 	if(cq->log)
-	   fprintf(cq->log,_("\nPara from %lXh to %lXh, j is %lXh "), (unsigned long)cq->para_fcFirst, cq->para_fcLim, (long)cq->ActualPos);
+	   fprintf(cq->log,_("\nPara from %lXh to %lXh, j is %lXh "), (unsigned long)cq->para_fcFirst, (long)cq->para_fcLim, (long)cq->ActualPos);
 	if (0 == cq->para_pendingclose)
 	  {  /* if there's no paragraph open, but there should be then I believe that the fcFirst search
 		has failed me, so I set it to now. I need to investigate this further. I believe it occurs
@@ -893,7 +893,8 @@ DWORD begincp, endcp;
 				  &cq->clx, cq->bteChpx, cq->posChpx,
 				  cq->char_intervals, cq->wpd);
 	    if(cq->log)
-		fprintf(cq->log,_("\nChar begins at %lXh ends %lXh, pos is %lXh "), (unsigned long)cq->char_fcFirst, cq->char_fcLim, cq->ActualPos);
+		fprintf(cq->log,_("\nChar begins at %lXh ends %lXh, pos is %lXh "), 
+				(unsigned long)cq->char_fcFirst, (unsigned long)cq->char_fcLim, (unsigned long)cq->ActualPos);
 	    if (0 == cq->char_pendingclose)
 		{  /* if there's no character run open, but there should be then I believe that the fcFirst search
 		      has failed me, so I set it to now. I need to investigate this further. */
@@ -1315,7 +1316,7 @@ DWORD begincp, endcp;
 			 cq->btePapx, cq->posPapx, cq->para_intervals, piececount,
 			 cq->wpd);
 	if(cq->log)
-	   fprintf(cq->log,_("\nPara from %lXh to %lXh, j is %lXh "), (unsigned long)cq->para_fcFirst, cq->para_fcLim, cq->ActualPos);
+	   fprintf(cq->log,_("\nPara from %lXh to %lXh, j is %lXh "), (unsigned long)cq->para_fcFirst, (unsigned long)cq->para_fcLim, (unsigned long)cq->ActualPos);
 	if (0 == cq->para_pendingclose)
 	  {  /* if there's no paragraph open, but there should be then I believe that the fcFirst search
 		has failed me, so I set it to now. I need to investigate this further. I believe it occurs
@@ -1373,7 +1374,7 @@ DWORD begincp, endcp;
 				  &cq->clx, cq->bteChpx, cq->posChpx,
 				  cq->char_intervals, cq->wpd);
 	    if(cq->log)
-		fprintf(cq->log,_("\nChar begins at %lXh ends %lXh, pos is %lXh "), cq->char_fcFirst, cq->char_fcLim, cq->ActualPos);
+		fprintf(cq->log,_("\nChar begins at %lXh ends %lXh, pos is %lXh "), cq->char_fcFirst, cq->char_fcLim, (unsigned long)cq->ActualPos);
 	    if (0 == cq->char_pendingclose)
 		{  /* if there's no character run open, but there should be then I believe that the fcFirst search
 		      has failed me, so I set it to now. I need to investigate this further. */
@@ -1436,7 +1437,7 @@ string temp_filename;
 
   DocumentStart=ftell(wpd);
 
-  fsize=filesize(wpd);
+  fsize = FileSize(wpd);
 
   Ver=FilForD.DocVersion>>8;
 
