@@ -17,8 +17,8 @@
 
 #define LineLength   80		/* Split lines after more than LineLength charcters */
 
-#define VersionWP2L	"3.109"
-#define VersionDate	"3 Oct 2022"  /* day (space) month (space) full year */
+#define VersionWP2L	"3.110"
+#define VersionDate	"7 Nov 2022"  /* day (space) month (space) full year */
 
 
 /* Constants for a flag InputPS */
@@ -83,7 +83,7 @@ extern const TStyleOpCl *StyleOpCl;
 int AbsolutePath(const char *TestedPath);
 FILE *OpenWrChk(const char *name, const char *type, FILE *Err);
 int  ReadAndSplitLine(FILE *fp, char *regel);
-long filesize(FILE *f);
+long FileSize(FILE *f);
 #define Rd_word(f,w) RdWORD_LoEnd(w,f);
 #define Rd_dword(f,d) RdDWORD_LoEnd(d,f);
 #define Wr_word(f,w) WrWORD_LoEnd(w,f);
@@ -484,7 +484,6 @@ extern LangItem LangTable[31];
 
 #ifdef __Stringa_h  //Only Strings related stuff
 temp_string Attributes2String(DWORD Attributes);
-string & fGets2(FILE *f, string & pstr,long MaxStrSize=0);
 temp_string MergePaths(const string & Path, const string & RelPath, bool EnsureTrail=true);
 void PutFormula(TconvertedPass1 *cq, char *Str,const TBox & Box);
 extern string RelativeFigDir, OutputDir;
